@@ -1,7 +1,7 @@
 # Copyright (c) 2007 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: CNic.pm,v 1.49 2008/02/05 11:07:48 gavin Exp $
+# $Id: CNic.pm,v 1.59 2009/08/28 11:59:53 oliver Exp $
 package WWW::CNic;
 use LWP;
 use LWP::ConnCache;
@@ -11,7 +11,7 @@ use Digest::MD5 qw(md5_hex);
 use vars qw($VERSION $CONNECTION_CACHE);
 use strict;
 
-our $VERSION = '0.25';
+our $VERSION = '0.30';
 
 =pod
 
@@ -48,7 +48,7 @@ WWW::CNic - a web-based API for the CentralNic domain registry system.
 
 =head1 DESCRIPTION
 
-C<WWW::CNic> provides a powerful object-oriented Perl interface to the CentralNic Toolkit system. This system provides a way for CentralNic resellers to automate all Reseller-Registry communication and provides a far more flexible and efficient solution than the combination of whois + e-mail automaton that most registries operate.
+C<WWW::CNic> provides a powerful object-oriented Perl interface to the CentralNic Toolkit system.
 
 The design of C<WWW::CNic> is inspired greatly by C<LWP>, which is a prerequisite. Essentially, making a transaction requires building a I<request> object, which is then executed and returns a I<response> object. While each transaction type (search, registration, modification...) requires a different set of data to be sent by the client, all the response objects have common properties, inherited from the C<WWW::CNic::Response> base class, with just a few extra methods for accessing specific information.
 
@@ -64,8 +64,7 @@ Installing C<WWW::CNic> is as simple as:
 	make
 	make install
 
-=head1 PREREQUISITES		$self->{_command} eq 'list_outstanding_domains'	&& return $self->_list_outstanding_domains();
-
+=head1 PREREQUISITES
 
 =over
 
@@ -79,7 +78,7 @@ An SSL toolkit (C<Crypt::SSLeay>, C<IO::Socket::SSL>) for doing HTTPS transactio
 
 =item 4
 
-C<Digest::MD5> is needed for encrypting passwords.
+C<Digest::MD5> is needed for hashing passwords.
 
 =back
 
@@ -97,15 +96,11 @@ The constructor for this class accepts the following options:
 
 =item 1
 
-C<username> - only needed for doing domain registrations and modifications. This is the User ID of your Reseller Handle.
+C<username> - only needed for doing domain registrations and modifications. This is the User ID of your Registrar Handle.
 
 =item 1
 
-C<password> - the password for your Reseller Handle.
-
-=item 2
-
-C<use_ssl> - when set to C<1>, causes all transactions to take place over a Secure Sockets Layer (SSL) connection. This is highly recommended for domain registration and modification transactions, although it's probably not needed for the other commands. In order to take advantage of this you need to have either the C<Crypt::SSLeay> or C<IO::Socket::SSL> modules installed. More information is available in the C<lwpcook> manpage.
+C<password> - the password for your Registrar Handle.
 
 =item 3
 
@@ -184,7 +179,7 @@ sub new {
 	$self->{_agent}->timeout($self->{_timeout} || 10);
 	$self->{_agent}->agent(sprintf('%s/%s (LWP %s, Perl %vd, %s)', $package, $VERSION, $LWP::VERSION, $^V, ucfirst($^O)));
 	$self->{_agent}->conn_cache($CONNECTION_CACHE) unless (!$self->{_keep_alive});
-	$self->{_base} = (defined($self->{_use_ssl}) && $self->{_use_ssl} == 1 ? 'https' : 'http').'://'.(defined($self->{_host}) ? $self->{_host} : 'toolkit.centralnic.com').'/srv';
+	$self->{_base} = 'http://' . (defined($self->{_host}) ? $self->{_host} : 'toolkit.centralnic.com').'/srv';
 	# bless into this package:
 	bless($self, $package);
 	return $self;
@@ -202,9 +197,11 @@ sub set {
 sub execute {
 	my $self = shift;
 	SWITCH: {
+		# No SSL/authentication required
 		$self->{_command} eq 'whois'			&& return $self->_whois();
 		$self->{_command} eq 'search'			&& return $self->_search();
 		$self->{_command} eq 'suffixes'			&& return $self->_suffixes();
+		# SSL/authentication required
 		$self->{_command} eq 'create_handle'		&& return $self->_create_handle();
 		$self->{_command} eq 'handle_info'		&& return $self->_handle_info();
 		$self->{_command} eq 'register'			&& return $self->_register();
@@ -234,8 +231,13 @@ sub execute {
 	}
 }
 
+#
+# No SSL/authentication required
+#
+
 sub _whois {
 	my $self = shift;
+	$self->{_base} =~ s/^https:/http:/g;	# No SSL required
 	die("Missing domain name") if $self->{_domain} eq '';
 	$self->{_response}->{_raw} = $self->_get(GET("$self->{_base}/wwwhois?domain=$self->{_domain}&test=$self->{_test}"));
 	use WWW::CNic::Response::Whois;
@@ -244,6 +246,7 @@ sub _whois {
 
 sub _search {
 	my $self = shift;
+	$self->{_base} =~ s/^https:/http:/g;	# No SSL required
 	die("Missing domain name") if $self->{_domain} eq '';
 	my $url = "$self->{_base}/search?domain=$self->{_domain}";
 	if (defined(@{$self->{_params}->{suffixlist}})) {
@@ -256,13 +259,19 @@ sub _search {
 
 sub _suffixes {
 	my $self = shift;
+	$self->{_base} =~ s/^https:/http:/g;	# No SSL required
 	$self->{_response}->{_raw} = $self->_get(GET("$self->{_base}/suffixes?test=$self->{_test}"));
 	use WWW::CNic::Response::Suffixes;
 	return WWW::CNic::Response::Suffixes->new($self->{_response}->{_raw});
 }
 
+#
+# SSL/authentication required
+#
+
 sub _create_handle {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Invalid type for handle") unless (ref($self->{_params}->{handle}) eq 'HASH');
 	my %params =  (
 		user		=> $self->{_username},
@@ -309,6 +318,7 @@ sub _create_handle {
 
 sub _handle_info {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	my %params =  (
 		user		=> $self->{_username},
 		password	=> $self->_crypt_md5($self->{_password}),
@@ -323,6 +333,7 @@ sub _handle_info {
 
 sub _register {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	my %args = @_;
 	die("Missing domain name") if $self->{_domain} eq '';
 	die("Missing username") if $self->{_username} eq '';
@@ -357,6 +368,9 @@ sub _register {
 		$dns_param	=> $dns,
 	);
 
+	$params{ahandle} = $self->{_params}->{ahandle} if (defined($self->{_params}->{ahandle}));
+	$params{bhandle} = $self->{_params}->{bhandle} if (defined($self->{_params}->{bhandle}));
+
 	$params{url} = $self->{_params}->{url} if ($self->{_params}->{url} ne '');
 
 	my $POST_URL = $self->{_base}.'/'.($args{idn} == 1 ? 'register_idn' : 'register');
@@ -380,6 +394,7 @@ sub _register {
 
 sub _register_atgb {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing domain name") if $self->{_domain} eq '';
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
@@ -411,6 +426,7 @@ sub _register_atgb {
 
 sub _modify {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing domain name") if $self->{_domain} eq '';
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
@@ -426,9 +442,15 @@ sub _modify {
 	if (defined($self->{_params}->{chandle})) {
 		$params{chandle} = (ref($self->{_params}->{chandle}) eq 'HASH' ? $self->_build_handle_string($self->{_params}->{chandle}) : $self->{_params}->{chandle});
 	}
+	if (defined($self->{_params}->{ahandle})) {
+		$params{ahandle} = $self->{_params}->{ahandle};
+	}
 	if (defined($self->{_params}->{thandle})) {
 		$params{thandle} = (ref($self->{_params}->{thandle}) eq 'HASH' ? $self->_build_handle_string($self->{_params}->{thandle}) : $self->{_params}->{thandle});
 	}
+	if (defined($self->{_params}->{bhandle})) {
+		$params{bhandle} = $self->{_params}->{bhandle};
+	}
 	$params{ttl} = int($self->{_params}->{ttl}) if (defined($self->{_params}->{ttl}));
 
 	if (defined($self->{_params}->{dns})) {
@@ -468,6 +490,7 @@ sub _modify {
 
 sub _modify_handle {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing handle ID") if ($self->{_params}->{handle} eq '');
@@ -497,10 +520,22 @@ sub _modify_handle {
 
 sub _upcoming_renewals {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
-	my $url = "$self->{_base}/upcoming_renewals?user=$self->{_username}&months=$self->{_months}&password=".$self->_crypt_md5($self->{_password}).'&test='.$self->{_test};
-	my $req = HTTP::Request->new(GET => $url);
+
+	my %params = (
+		user		=> $self->{_username},
+		password	=> $self->_crypt_md5($self->{_password}),
+		test		=> $self->{_test},
+		months		=> $self->{_months},
+	);
+
+	foreach my $key (keys(%{$self->{_params}})) {
+		$params{$key} = $self->{_params}->{$key};
+	}
+
+	my $req = POST("$self->{_base}/upcoming_renewals", \%params);
 	$self->{_response}->{_raw} = $self->_get($req);
 	use WWW::CNic::Response::Renewals;
 	return WWW::CNic::Response::Renewals->new($self->{_response}->{_raw});
@@ -508,6 +543,7 @@ sub _upcoming_renewals {
 
 sub _list_domains {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	my %params = 	(
@@ -526,6 +562,7 @@ sub _list_domains {
 
 sub _issue_renewals {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domains") if scalar(@{$self->{_params}->{domains}}) < 1;
@@ -549,6 +586,7 @@ sub _issue_renewals {
 
 sub _get_pricing {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	my %params = (
@@ -566,6 +604,7 @@ sub _get_pricing {
 
 sub _delete_domain {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domain")	if $self->{_domain}   eq '';
@@ -575,6 +614,7 @@ sub _delete_domain {
 				test		=> $self->{_test},
 				domain		=> $self->{_domain},
 				reason		=> $self->{_reason} || $self->{_params}->{reason},
+				immediate	=> $self->{_immediate},
 	);
 	die("Missing reason") if ($params{reason}  eq '');
 	$params{immediate} = 1 if ($self->{_params}->{immediate});
@@ -587,6 +627,7 @@ sub _delete_domain {
 
 sub _decline_domain {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domain")	if $self->{_domain}   eq '';
@@ -605,6 +646,7 @@ sub _decline_domain {
 
 sub _undecline_domain {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domain")	if $self->{_domain}   eq '';
@@ -623,6 +665,7 @@ sub _undecline_domain {
 
 sub _start_transfer {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domains") if scalar(@{$self->{_params}->{domains}}) < 1;
@@ -636,6 +679,11 @@ sub _start_transfer {
 		$params{"domains[$i]"} = $domain;
 		$i++;
 	}
+	$i = 0;
+	foreach my $info(@{$self->{_params}->{authinfo}}) {
+		$params{"authinfo[$i]"} = $info;
+		$i++;
+	}
 	my $url = "$self->{_base}/start_transfer";
 	my $req = POST($url, \%params);
 	$self->{_response}->{_raw} = $self->_get($req);
@@ -645,6 +693,7 @@ sub _start_transfer {
 
 sub _check_transfer {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domain")	if $self->{_domain}   eq '';
@@ -663,6 +712,7 @@ sub _check_transfer {
 
 sub _cancel_transfer {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domain")	if $self->{_domain}   eq '';
@@ -681,6 +731,7 @@ sub _cancel_transfer {
 
 sub _reactivate_domain {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domain")	if $self->{_domain}   eq '';
@@ -690,7 +741,8 @@ sub _reactivate_domain {
 				test		=> $self->{_test},
 				domain		=> $self->{_domain},
 	);
-	$params{email} = $self->{_email} if (defined($self->{email}));
+	$params{email} = $self->{_email} if (defined($self->{_email}));
+	$params{period} = $self->{_period} if (defined($self->{_period}));
 	my $url = "$self->{_base}/reactivation_request";
 	my $req = POST($url, \%params);
 	$self->{_response}->{_raw} = $self->_get($req);
@@ -700,6 +752,7 @@ sub _reactivate_domain {
 
 sub _push_domain {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domain")	if $self->{_domain}   eq '';
@@ -720,6 +773,7 @@ sub _push_domain {
 
 sub _auth_info {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domain")	if $self->{_domain}   eq '';
@@ -738,6 +792,7 @@ sub _auth_info {
 
 sub _poll_transfers {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	my %params = (
@@ -754,6 +809,7 @@ sub _poll_transfers {
 
 sub _approve_transfer {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domain")	if $self->{_domain}   eq '';
@@ -772,6 +828,7 @@ sub _approve_transfer {
 
 sub _reject_transfer {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domain")	if $self->{_domain}   eq '';
@@ -790,6 +847,7 @@ sub _reject_transfer {
 
 sub _list_outstanding_domains {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	my %params = (
@@ -806,6 +864,7 @@ sub _list_outstanding_domains {
 
 sub _submit_payment_batch {
 	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
 	die("Missing domains") if scalar(@{$self->{_params}->{domains}}) < 1;
