@@ -1,7 +1,7 @@
 # Copyright (c) 2007 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: Cookbook.pm,v 1.42 2008/02/05 11:07:48 gavin Exp $
+# $Id: Cookbook.pm,v 1.46 2009/08/28 11:59:54 oliver Exp $
 
 package WWW::CNic::Cookbook;
 use vars qw($VERSION);
@@ -14,7 +14,7 @@ WWW::CNic::Cookbook - The WWW::CNic Cookbook
 
 =head1 Description
 
-This document provides a fairly complete explanation of how to implement basic Reseller-Registry functions with CentralNic using C<WWW::CNic>.
+This document provides a fairly complete explanation of how to implement basic Registrar-Registry functions with CentralNic using C<WWW::CNic>.
 
 This document is a work in progress, if you want to see something in it that isn't, or find an error, please let us know by e-mailing L<toolkit@centralnic.com>.
 
@@ -39,7 +39,6 @@ CentralNic's range of available domain names changes occasionally and you may wa
 	# create a request object:
 	my $query = WWW::CNic->new(
 		command	=> 'suffixes',
-		use_ssl	=> 0,
 	);
 
 	# execute the query to return a response object:
@@ -69,7 +68,6 @@ Here's how you might do a check against a particular domain name:
 
 	my $query = WWW::CNic->new(
 		command	=> 'search',
-		use_ssl	=> 0,
 		domain	=> $domain,
 	);
 
@@ -102,7 +100,6 @@ For example:
 	my $query = WWW::CNic->new(
 		command	=> 'whois',
 		domain	=> $domain,
-		use_ssl	=> 0,
 	);
 
 	my $response = $query->execute;
@@ -170,7 +167,6 @@ B<Address data:> handles in the CentralNic database follow one of two "styles":
 	use WWW::CNic;
 
 	my $query = WWW::CNic->new(
-		use_ssl		=> 1,
 		command		=> 'auth_info',
 		domain		=> 'example.uk.com',
 		username	=> $handle,
@@ -187,7 +183,7 @@ B<Address data:> handles in the CentralNic database follow one of two "styles":
 
 	}
 
-This command is used to retrieve the transfer code for a domain name. Those registrars who use our EPP system are required to provide a security code when they initiate a transfer request, which they get from the registrant, who in turn gets it from the losing registrar. Resellers are required to provide this code to registrants upon request.
+This command is used to retrieve the transfer code for a domain name. Those registrars who use our EPP system are required to provide a security code when they initiate a transfer request, which they get from the registrant, who in turn gets it from the losing registrar. Registrars are required to provide this code to registrants upon request.
 
 =head2 Getting Detailed Information About a Handle
 
@@ -197,7 +193,6 @@ This command can be used to retrieve information about a handle I<for which you
 
 	my $query = WWW::CNic->new(
 		command		=> 'handle_info',
-		use_ssl		=> 0,
 		username	=> $handle,
 		password	=> $passwd,
 	);
@@ -231,7 +226,6 @@ To do so, use the C<create_handle> command:
 	use WWW::CNic;
 
 	my $query = WWW::CNic->new(
-		use_ssl		=> 1,
 		command		=> 'create_handle',
 		username	=> $handle,
 		password	=> $passwd,
@@ -295,14 +289,11 @@ You can use the C<handle()> method to return the ID of the created handle, for u
 
 =head2 Registering a Domain Name
 
-You can register a domain using C<WWW::CNic> in real-time - no waiting for automaton responses to come through!
-
-We recommend that you enable SSL when making registration and modification requests. This is to protect your password when it's sent. WWW::CNic supports SSL communications transparently, since it uses C<LWP> to do all HTTP communication. C<LWP> will handle SSL if the C<Crypt::SSLeay> or C<IO::Socket::SSL> modules have been installed.
+We require that you use SSL when making registration and modification requests. WWW::CNic supports SSL communications transparently, since it uses C<LWP> to do all HTTP communication. C<LWP> will handle SSL if the C<Crypt::SSLeay> or C<IO::Socket::SSL> modules have been installed.
 
 	use WWW::CNic;
 
 	my $query =	WWW::CNic->new(
-		use_ssl		=> 1,
 		command		=> 'register',
 		domain		=> 'example.uk.com',
 		username	=> $handle,
@@ -336,7 +327,7 @@ We recommend that you enable SSL when making registration and modification reque
 
 IMPORTANT NOTE: the details you enter for the Client Handle (C<chandle>) should be the contact details of your customer.
 
-In order to make a registration transaction, you need to supply the C<username> and C<password> parameters - these correspond to your Reseller Handle's ID and password. Your password is C<crypt()>ed before it is sent to provide a minimum of security if you can't use SSL.
+In order to make a registration transaction, you need to supply the C<username> and C<password> parameters - these correspond to your Registrar Handle's ID and password. Your password is C<crypt()>ed before it is sent.
 
 You need to set a range of extra parameters to register a domain. These are explained below.
 
@@ -388,7 +379,6 @@ You can use C<WWW::CNic> to do real-time modification of a domain. The procedure
 	use WWW::CNic;
 
 	my $query =	WWW::CNic->new(
-		use_ssl		=> 1,
 		command		=> 'modify',
 		domain		=> 'example.uk.com',
 		username	=> $handle,
@@ -438,14 +428,13 @@ If this parameter contains the special keyword C<'drop'> then the web forwarding
 
 =head2 Modifying a Handle
 
-When a handle is created by the C<create_handle> or C<register> commands, or via other interfaces such as the Reseller Console, it is associated with your account. This allows you to update the contact details for that handle.
+When a handle is created by the C<create_handle> or C<register> commands, or via other interfaces such as the Registrar Console, it is associated with your account. This allows you to update the contact details for that handle.
 
 B<IMPORTANT>: this command B<must not> be used to completely change the contact details for a handle for a domain name. Instead you should use the C<modify> function to change the ID of the handle on the domain name (see above). This function is only for incremental changes to contact details.
 
 	use WWW::CNic;
 
 	my $query = WWW::CNic->new(
-		use_ssl		=> 1,
 		command		=> 'modify_handle',
 		username	=> $handle,
 		password	=> $passwd,
@@ -501,7 +490,6 @@ The meaning of these fields is identical to those described in the "Creating a H
 	use strict;
 
 	my $query = WWW::CNic->new(
-		use_ssl		=> 0,
 		command		=> 'issue_renewals',
 		username	=> $handle,
 		password	=> $passwd
@@ -545,7 +533,6 @@ Under normal circumstances, a renewal invoice or proforma is not issued right aw
 =head2 Deleting a Domain Name
 
 	my $query = WWW::CNic->new(
-		use_ssl		=> 1,
 		command		=> 'delete',
 		domain		=> $domain,
 		username	=> $handle,
@@ -575,7 +562,6 @@ In accordance with our policy, an e-mail will be sent to the domain's Client Han
 =head2 Declining Renewal for a Domain Name
 
 	my $query = WWW::CNic->new(
-		use_ssl		=> 1,
 		command		=> 'decline',
 		domain		=> $domain,
 		username	=> $handle,
@@ -597,7 +583,6 @@ I<Declining renewal> means that a domain name will not be renewed when it expire
 =head2 Reversing a Declined Renewal
 
 	my $query = WWW::CNic->new(
-		use_ssl		=> 1,
 		command		=> 'undecline',
 		domain		=> $domain,
 		username	=> $handle,
@@ -625,7 +610,6 @@ Domain Administration team. The domain will then be placed back on the "Live"
 status, and a registration or renewal invoice will be re-issed.
 
 	my $query = WWW::CNic->new(
-		use_ssl		=> 1,
 		command		=> 'reactivate',
 		domain		=> $domain,
 		username	=> $handle,
@@ -633,6 +617,7 @@ status, and a registration or renewal invoice will be re-issed.
 	);
 
 	$query->set('email', 'yourname@example.com');
+	$query->set('period', 1); # renewal period in years
 
 	my $response = $query->execute;
 
@@ -645,12 +630,12 @@ status, and a registration or renewal invoice will be re-issed.
 	}
 
 If you specify an C<email> parameter, our administrators will send a notification
-to that address.
+to that address. C<period> may be any integer between 1 and 10.
 
-=head2 Pushing a Domain Name To Another Reseller
+=head2 Pushing a Domain Name To Another Registrar
 
 You may request that a domain name on your account be "pushed" to another
-reseller account. A domain name may only be pushed if:
+registrar account. A domain name may only be pushed if:
 
 =over
 
@@ -658,12 +643,11 @@ reseller account. A domain name may only be pushed if:
 
 =item the domain name's status is "Live"
 
-=item the "gaining" reseller has not opted-out of the "push" system
+=item the "gaining" registrar has not opted-out of the "push" system
 
 =back
 
 	my $query = WWW::CNic->new(
-		use_ssl		=> 1,
 		command		=> 'push_domain',
 		username	=> $handle,
 		password	=> $password,
@@ -686,14 +670,14 @@ from your account. Any outstanding invoices will be credited to you and
 re-issued to the gaining account.
 
 If you are also listed as Technical Contact for the domain name, then this
-handle will also be changed to the gaining reseller account.
+handle will also be changed to the gaining registrar account.
 
 This command will also transfer sponsorship of the client and/or technical
 handles for the domain name, but only if these handles are not associated with
 any other domains on your account. Where a handle is associated with domains on
-multiple reseller accounts, the handle becomes "unsponsored".
+multiple registrar accounts, the handle becomes "unsponsored".
 
-We will send an e-mail to the gaining reseller notifying them of the domain
+We will send an e-mail to the gaining registrar notifying them of the domain
 transfer.
 
 =head1 Transferring Domain Names
@@ -715,7 +699,6 @@ You can B<start> a transfer process for one or more domain names using the C<sta
 6. If the transfer is not explicitly I<approved> or I<rejected> by the B<losing> registrar B<within five calendar days>, then the transfer is automatically marked as C<rejected>. The transfer may still be actioned if the B<gaining> registrar can acquire written authorisation (ideally on company letterhead) from the Registrant.
 
 	my $query = WWW::CNic->new(
-		use_ssl		=> 1,
 		command		=> 'start_transfer',
 		username	=> $handle,
 		password	=> $password,
@@ -793,7 +776,7 @@ The C<transfers()> method returns an array of hashrefs containing transfer infor
 
 	}
 
-If you are the gaining reseller for a domain transfer, you can cancel the request before it is approved or rejected by the losing reseller. If the transfer has already been approved or rejected, then the server will return an error.
+If you are the gaining registrar for a domain transfer, you can cancel the request before it is approved or rejected by the losing registrar. If the transfer has already been approved or rejected, then the server will return an error.
 
 =head2 Checking the Status of a Domain Transfer
 
@@ -959,7 +942,7 @@ You can use this command to retrieve a list of domains against your handle. The
 
 	}
 
-This command allows you to retrieve pricing information for your reseller account. You must specify a C<type> parameter, which can be either 'C<registration>' (the default) or 'C<renewal>'.
+This command allows you to retrieve pricing information for your registrar account. You must specify a C<type> parameter, which can be either 'C<registration>' (the default) or 'C<renewal>'.
 
 =head2 Listing Outstanding Domains
 
